# Poll API Deprecation: Transition to the New Survey API
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#overview)
  * [Transition Timeline](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#transition-timeline)
  * [Why We're Making These Changes](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#why-we're-making-these-changes)
  * [Important: Poll API v2 is Now Deprecated](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#important:-poll-api-v2-is-now-deprecated)
  * [What's Changing](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#what's-changing)
  * [Key Changes](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#key-changes)
  * [Breaking Changes](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#breaking-changes)
  * [What You Need to Do](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api#what-you-need-to-do)


View all
Learn what's changing and how to prepare for the transition to the new API for surveys.
